$wnd.rstudio.runAsyncCallback9("function QYj(a){this.a=a}\nfunction IXj(a){a.J.BI();M8e(a.j.o)}\nfunction GXj(a){NVi(a.j);B$f(a.a,'Load History','loadhistory')}\nfunction HXj(a){NVi(a.j);G$f(a.a,'Save History As','.Rhistory',false,'savehistory')}\nfunction MYj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=tZj(a.a.b.a);qQi(a.a,a.a.a)}switch(a.c){case 1:a.a.a.J.zI();break;case 2:a.a.a.J.AI();break;case 3:GXj(a.a.a);break;case 4:HXj(a.a.a);break;case 5:IXj(a.a.a);break;case 6:a.a.a.J.CI();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nD6c(514,1,eio);_.en=function PYj(){MYj((new QYj(this)).a)};D6c(6458,1,HSn,QYj);_.gn=function RYj(){MYj(this.a)};var Ybc=mQd(6458);uJn(hm)(9);\n//# sourceURL=rstudio-9.js\n")
