/* THIS THEME WAS AUTOGENERATED BY Theme.tmpl.css (UUID: %uuid%) */

.%cssClass% .ace_gutter {
  background: %gutterBg%;
  color: %gutterFg%;
}

.%cssClass% .ace_print-margin {
  width: 1px;
  background: %printMargin%;
}

.%cssClass% {
  background-color: %background%;
  color: %foreground%;
}

.%cssClass% .ace_cursor {
  color: %cursor%;
}

.%cssClass% .ace_marker-layer .ace_selection {
  background: %selection%;
}

.%cssClass%.ace_multiselect .ace_selection.ace_start {
  box-shadow: 0 0 3px 0px %background%;
  border-radius: 2px;
}

.%cssClass% .ace_marker-layer .ace_step {
  background: %step%;
}

.%cssClass% .ace_marker-layer .ace_bracket {
  margin: -1px 0 0 -1px;
  border: 1px solid %bracket%;
}

.%cssClass% .ace_marker-layer .ace_active-line {
  background: %active_line%;
}

.%cssClass% .ace_gutter-active-line {
  background-color: %active_line%;
}

.%cssClass% .ace_marker-layer .ace_selected-word {
  %selected_word_highlight%
}

.%cssClass% .ace_fold {
  background-color: %fold%;
  border-color: %foreground%;
}

.%cssClass% .ace_invisible {
  color: %invisible%;
}

