"undefined"===typeof PDFJS&&(("undefined"!==typeof window?window:this).PDFJS={});
(function(){function a(a,d){return new b(this.slice(a,d))}function c(a,b){2>arguments.length&&(b=0);for(var c=0,g=a.length;c<g;++c,++b)this[b]=a[c]&255}function b(b){var d,e,g;if("number"===typeof b){d=[];for(e=0;e<b;++e)d[e]=0}else if("slice"in b)d=b.slice(0);else{d=[];for(e=0,g=b.length;e<g;++e)d[e]=b[e]}d.subarray=a;d.buffer=d;d.byteLength=d.length;d.set=c;"object"===typeof b&&b.buffer&&(d.buffer=b.buffer);return d}"undefined"!==typeof Uint8Array?("undefined"===typeof Uint8Array.prototype.subarray&&
(Uint8Array.prototype.subarray=function(b,a){return new Uint8Array(this.slice(b,a))},Float32Array.prototype.subarray=function(b,a){return new Float32Array(this.slice(b,a))}),"undefined"===typeof Float64Array&&(window.Float64Array=Float32Array)):(window.Uint8Array=b,window.Int8Array=b,window.Uint32Array=b,window.Int32Array=b,window.Uint16Array=b,window.Float32Array=b,window.Float64Array=b)})();(function(){window.URL||(window.URL=window.webkitURL)})();
(function(){if("undefined"!==typeof Object.defineProperty){var a=!0;try{Object.defineProperty(new Image,"id",{value:"test"});var c=function(){};c.prototype={get id(){}};Object.defineProperty(new c,"id",{value:"",configurable:!0,enumerable:!0,writable:!1})}catch(b){a=!1}if(a)return}Object.defineProperty=function(b,a,c){delete b[a];"get"in c&&b.__defineGetter__(a,c.get);"set"in c&&b.__defineSetter__(a,c.set);"value"in c&&(b.__defineSetter__(a,function(b){this.__defineGetter__(a,function(){return b});
return b}),b[a]=c.value)}})();
(function(){var a=XMLHttpRequest.prototype,c=new XMLHttpRequest;"overrideMimeType"in c||Object.defineProperty(a,"overrideMimeType",{value:function(){}});"responseType"in c||(PDFJS.disableWorker=!0,Object.defineProperty(a,"responseType",{get:function(){return this._responseType||"text"},set:function(b){if("text"===b||"arraybuffer"===b)this._responseType=b,"arraybuffer"===b&&"function"===typeof this.overrideMimeType&&this.overrideMimeType("text/plain; charset=x-user-defined")}}),"undefined"!==typeof VBArray?
Object.defineProperty(a,"response",{get:function(){return"arraybuffer"===this.responseType?new Uint8Array((new VBArray(this.responseBody)).toArray()):this.responseText}}):Object.defineProperty(a,"response",{get:function(){if("arraybuffer"!==this.responseType)return this.responseText;var b=this.responseText,a,c=b.length,e=new Uint8Array(c);for(a=0;a<c;++a)e[a]=b.charCodeAt(a)&255;return e.buffer}}))})();
(function(){"btoa"in window||(window.btoa=function(a){var c="",b,f;for(b=0,f=a.length;b<f;b+=3)var d=a.charCodeAt(b)&255,e=a.charCodeAt(b+1)&255,g=a.charCodeAt(b+2)&255,h=(d&3)<<4|e>>4,e=b+1<f?(e&15)<<2|g>>6:64,g=b+2<f?g&63:64,c=c+("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=".charAt(d>>2)+"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=".charAt(h)+"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=".charAt(e)+"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=".charAt(g));
return c})})();(function(){"atob"in window||(window.atob=function(a){a=a.replace(/=+$/,"");if(1===a.length%4)throw Error("bad atob input");for(var c=0,b,f,d=0,e="";f=a.charAt(d++);~f&&(b=c%4?64*b+f:f,c++%4)&&(e+=String.fromCharCode(255&b>>(-2*c&6))))f="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=".indexOf(f);return e})})();
(function(){"undefined"===typeof Function.prototype.bind&&(Function.prototype.bind=function(a){var c=this,b=Array.prototype.slice.call(arguments,1);return function(){var f=b.concat(Array.prototype.slice.call(arguments));return c.apply(a,f)}})})();
(function(){"dataset"in document.createElement("div")||Object.defineProperty(HTMLElement.prototype,"dataset",{get:function(){if(this._dataset)return this._dataset;for(var a={},c=0,b=this.attributes.length;c<b;c++){var f=this.attributes[c];if("data-"===f.name.substring(0,5)){var d=f.name.substring(5).replace(/\-([a-z])/g,function(b,a){return a.toUpperCase()});a[d]=f.value}}Object.defineProperty(this,"_dataset",{value:a,writable:!1,enumerable:!1});return a},enumerable:!0})})();
(function(){function a(b,a,c,e){var g=(b.className||"").split(/\s+/g);""===g[0]&&g.shift();var h=g.indexOf(a);0>h&&c&&g.push(a);0<=h&&e&&g.splice(h,1);b.className=g.join(" ");return 0<=h}if(!("classList"in document.createElement("div"))){var c={add:function(b){a(this.element,b,!0,!1)},contains:function(b){return a(this.element,b,!1,!1)},remove:function(b){a(this.element,b,!1,!0)},toggle:function(b){a(this.element,b,!0,!0)}};Object.defineProperty(HTMLElement.prototype,"classList",{get:function(){if(this._classList)return this._classList;
var b=Object.create(c,{element:{value:this,writable:!1,enumerable:!0}});Object.defineProperty(this,"_classList",{value:b,writable:!1,enumerable:!1});return b},enumerable:!0})}})();
(function(){"console"in window?"bind"in console.log||(console.log=function(a){return function(c){return a(c)}}(console.log),console.error=function(a){return function(c){return a(c)}}(console.error),console.warn=function(a){return function(c){return a(c)}}(console.warn)):window.console={log:function(){},error:function(){},warn:function(){}}})();
(function(){function a(b){c(b.target)&&b.stopPropagation()}function c(b){return b.disabled||b.parentNode&&c(b.parentNode)}-1!==navigator.userAgent.indexOf("Opera")&&document.addEventListener("click",a,!0)})();(function(){0<=navigator.userAgent.indexOf("Trident")&&(PDFJS.disableCreateObjectURL=!0)})();(function(){"language"in navigator||(PDFJS.locale=navigator.userLanguage||"en-US")})();
(function(){var a=0<Object.prototype.toString.call(window.HTMLElement).indexOf("Constructor"),c=/Android\s[0-2][^\d]/.test(navigator.userAgent),b=/Chrome\/(39|40)\./.test(navigator.userAgent);if(a||c||b)PDFJS.disableRange=!0,PDFJS.disableStream=!0})();(function(){if(!history.pushState||0<=navigator.userAgent.indexOf("Android 2."))PDFJS.disableHistory=!0})();
(function(){if(window.CanvasPixelArray)"function"!==typeof window.CanvasPixelArray.prototype.set&&(window.CanvasPixelArray.prototype.set=function(b){for(var a=0,c=this.length;a<c;a++)this[a]=b[a]});else{var a=!1;0<=navigator.userAgent.indexOf("Chrom")?a=(a=navigator.userAgent.match(/Chrom(e|ium)\/([0-9]+)\./))&&21>parseInt(a[2]):0<=navigator.userAgent.indexOf("Android")?a=/Android\s[0-4][^\d]/g.test(navigator.userAgent):0<=navigator.userAgent.indexOf("Safari")&&(a=(a=navigator.userAgent.match(/Version\/([0-9]+)\.([0-9]+)\.([0-9]+) Safari\//))&&
6>parseInt(a[1]));if(a){var a=window.CanvasRenderingContext2D.prototype,c=a.createImageData;a.createImageData=function(a,f){var d=c.call(this,a,f);d.data.set=function(a){for(var b=0,c=this.length;b<c;b++)this[b]=a[b]};return d};a=null}}})();
(function(){function a(a){window.setTimeout(a,20)}/(iPad|iPhone|iPod)/g.test(navigator.userAgent)?window.requestAnimationFrame=a:"requestAnimationFrame"in window||(window.requestAnimationFrame=window.mozRequestAnimationFrame||window.webkitRequestAnimationFrame||a)})();(function(){var a=/(iPad|iPhone|iPod)/g.test(navigator.userAgent),c=/Android/g.test(navigator.userAgent);if(a||c)PDFJS.maxCanvasPixels=5242880})();
(function(){0<=navigator.userAgent.indexOf("Trident")&&window.parent!==window&&(PDFJS.disableFullscreen=!0)})();(function(){"currentScript"in document||Object.defineProperty(document,"currentScript",{get:function(){var a=document.getElementsByTagName("script");return a[a.length-1]},enumerable:!0,configurable:!0})})();
