$wnd.rstudio.runAsyncCallback17("function vLk(a){this.a=a}\nfunction pUk(a){this.a=a}\nfunction rUk(a,b){this.a=a;this.b=b}\nfunction JVl(a,b){this.a=a;this.b=b}\nfunction dWl(a,b){this.a=a;this.b=b}\nfunction jVm(a,b){iVm();this.b=a;this.a=b}\nfunction YGm(a,b){jZg(a.u,b)}\nfunction QHl(a,b){YGm(a.ub,b)}\nfunction dKk(a){V$f(a.n,a.c,null)}\nfunction eKk(a){V$f(a.n,a.g,null)}\nfunction rKk(a){IKk(a.o,a.g,s1o,null)}\nfunction wKk(a){IKk(a.o,a.g,'next',null)}\nfunction yKk(a){IKk(a.o,a.g,'prev',null)}\nfunction zKk(a){IKk(a.o,a.g,'refresh',null)}\nfunction fKk(a){V$f(a.n,a.g+'?print-pdf',null)}\nfunction erg(a){return {items:a}}\nfunction LPk(a,b){var c;c=a;XHl(c,b.a)}\nfunction KPk(a,b){gn((_m(),$m),new rUk(b,a))}\nfunction JHl(a,b){gn((_m(),$m),new dWl(a,b))}\nfunction XHl(a,b){_Ym(a.w,Fno,false)?fGl(a,new JVl(a,b)):r$l(a._,b)}\nfunction ZJk(a,b){YRd(b.substr(0,4),WNn)||(b=u_h(a.p,b));return b}\nfunction jZg(a,b){a.d.navigateToPresentationEditorLocation(b)}\nfunction PGf(a){$wnd.desktop.setPresentationUrl(a)}\nfunction cKk(a){!!a.b&&ZIf(a.k,new jVm((xse(),Pse(a.b.source_file,false,-1,0)),$qg(a.d,a.a,a.e)),false)}\nfunction _qg(a,b){var c,d,e,f;b==-1&&(b=a.auto_slide_level);f=Zqg(a,b,true);for(c=0;c<f.length;c++){e=f[c];for(d=0;d<e.items.length;d++){if(YRd(e.items[d].type,_co))return c}}return 0}\nfunction $qg(a,b,c){var d,e,f,g,h;c==-1&&(c=b.auto_slide_level);h=Zqg(b,c,false);if(a<h.length){g=h[a];zl(g.items,brg(g.items[0].row))}e=[];for(d=0;d<h.length;d++){g=h[d];for(f=0;f<g.items.length;f++){xl(e,g.items[f])}}return arg(e,b.auto_slide_level)}\nfunction r$l(a,b){var c,d,e,f,g,h,i;e=q$l(a).items;d=[];for(g=0;g<e.length;g++){h=e[g];YRd(h.type,_co)||(d[d.length]=h,undefined)}c=-1;i=b.items;for(f=0;f<i.length;f++){if(YRd(i[f].type,_co)){c=f;break}}if(c>=0){h=d[c];!!h&&fnl(a.a,f_m(h.row,0),true)}}\nfunction Zqg(a,b,c){var d,e,f,g,h,i;i=[];g=a.items;for(d=0;d<g.length;d++){f=g[d];e=i.length==0||YRd(f.type,sLn)||YRd(f.type,'hr')||YRd(f.type,RKn)&&f.level<=b;if(e){h=erg([]);xl(h.items,f);i[i.length]=h}else (c||!YRd(f.type,_co))&&xl(i[i.length-1].items,f)}return i}\nfunction gKk(a,b){var c,d;c=b.a;d=ZJk(a,c.url);a.o=_qg(b.a.editor_state,b.a.slide_level);a.o==0&&a.d!=0&&(a.o=a.d);NVi(a.j);if(!YRd(d,a.g)||!a.j.o){a.g=d;a.c=d;a.b=c.quarto_navigation;a.a=c.editor_state;a.e=c.slide_level;(QFf()||!!$wnd.remoteDesktop)&&PGf(a.g);vKk(a.j,a.g,a.b)}else{zKk(a.j)}}\nfunction vKk(a,b,c){var d;(QFf()||!!$wnd.remoteDesktop)&&(Rce(b)?(Oh(a.d).removeAttribute(Qco),undefined):(Oh(a.d).setAttribute(Qco,Anp),undefined));a.b=b;a.o=null;a.g=null;d=Qh(a.d);d>0&&yi(a,new mqe(AK(d*0.6666666666666666)+((a.K?Ph(a.K):0)+(a.O?Ph(a.O):0))));kxd(a.d,a.b);c.is_website?nXh(a.i):mXh(a.i,c.source_file,c.output_file);Mnf(a.p)}\nfunction rLk(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=WLk(a.a.b.a);qQi(a.a,a.a.a)}switch(a.c){case 1:a.a.a.J.zI();break;case 2:a.a.a.J.AI();break;case 3:cKk(a.a.a);break;case 4:rKk(a.a.a.j);break;case 5:wKk(a.a.a.j);break;case 6:dKk(a.a.a);break;case 7:eKk(a.a.a);break;case 8:yKk(a.a.a.j);break;case 9:fKk(a.a.a);break;case 10:gKk(a.a.a,a.b[0]);break;case 11:zKk(a.a.a.j);break;case 12:a.a.a.J.BI();break;case 13:a.a.a.J.CI();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nD6c(302,1,eio);_.en=function uLk(){rLk((new vLk(this)).a)};D6c(6542,1,HSn,vLk);_.gn=function wLk(){rLk(this.a)};var eoc=mQd(6542);D6c(3154,1,CSn,pUk);_.du=function qUk(a){KPk(this.a,a)};var Frc=mQd(3154);D6c(3153,1,VLn,rUk);_.gn=function sUk(){LPk(this.a,this.b)};var Grc=mQd(3153);D6c(4405,1,HSn,JVl);_.gn=function KVl(){JHl(this.a,this.b)};var lGc=mQd(4405);D6c(4404,1,VLn,dWl);_.gn=function eWl(){QHl(this.a,this.b)};var wGc=mQd(4404);D6c(3197,CNn,{},jVm);_.Vn=function kVm(a){var b,c;b=(c=Ygg(a.k,this.b),!!c&&tK(c,80)?c:(Rgg(),Mgg));iYk(a.b,this.b,b,new pUk(this))};_.Xn=function mVm(){return hVm};_.Wn=function lVm(){return hVm};var fVc=mQd(3197);uJn(hm)(17);\n//# sourceURL=rstudio-17.js\n")
