$wnd.rstudio.runAsyncCallback3("function CRi(a){this.a=a}\nfunction ERi(a){this.a=a}\nfunction NRi(a){this.a=a}\nfunction GBe(a,b){var c;for(c=0;c<a.q.a.length;c++){if(lpd(a.q,c).qQ==b){uEe(a.t,lRd(c));break}}}\nfunction BRi(a,b){this.c=a;this.b=SAi(a.c,Ixo,Jxo,Kxo,mUn).oI();this.a=SAi(a.c,Lxo,Mxo,Nxo,Oxo).oI();xi(b,new CRi(this),aE?aE:(aE=new vB))}\nfunction zRi(a){var b;b=ARi(a,'weaving Rnw files',a.b,SAi(a.c.c,Ixo,Jxo,Kxo,mUn));b||ARi(a,'LaTeX typesetting',a.a,SAi(a.c.c,Lxo,Mxo,Nxo,Oxo))}\nfunction xRi(a,b,c){var d;d=gMi(a.b.a);LBe(d,rDi(qRg((rzf(),qzf).a)));!!b&&GBe(d,b);RBe(d,c);Fte(d,true);new BRi(a,d);(QFf()||!!$wnd.remoteDesktop)&&UFf()}\nfunction JRi(a){try{if(a.c<0)return;!a.a.a&&(a.a.a=NYi(a.a.b.a));switch(a.c){case 1:xRi(a.a.a,null,true);break;case 2:xRi(a.a.a,a.b[0],UPd(a.b[1]));}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nfunction ARi(a,b,c,d){if(zK(c)!==zK(d.oI())&&zK(d.qr())!==zK(d.oI())){c9d(2,'Project Option Unchanged','You changed the global option for '+b+gSn+d.oI()+', however the current project is still configured to use '+d.qr()+'.\\n\\nDo you want to edit the options for the current project as well?',new ERi(a),true);return true}else{return false}}\nD6c(2884,1,{},BRi);var oVb=mQd(2884);D6c(2885,1,BQn,CRi);_.so=function DRi(a){zRi(this.a)};var mVb=mQd(2885);D6c(2886,1,gTn,ERi);_.gn=function FRi(){Xee(this.a.c.a.hh)};var nVb=mQd(2886);D6c(632,1,eio);_.en=function MRi(){JRi((new NRi(this)).a)};D6c(2940,1,HSn,NRi);_.gn=function ORi(){JRi(this.a)};var pVb=mQd(2940);uJn(hm)(3);\n//# sourceURL=rstudio-3.js\n")
